@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2018 Canonical, Ltd.
+ * Copyright (C) 2013-2019 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,6 +37,7 @@
 #include <limits.h>
 #include <grp.h>
 #include <pwd.h>
+#include <bsd/string.h>
 
 #include "list.h"
 #include "json.h"
@@ -45,7 +46,6 @@
 #include "syscall.h"
 #include "timeval.h"
 #include "fnotify.h"
-#include "event.h"
 #include "cpustat.h"
 #include "mem.h"
 #include "net.h"
@@ -320,7 +320,7 @@ static const char *find_executable(const char *filename)
 			fprintf(stderr, "executable name too long.\n");
 			health_check_exit(EXIT_FAILURE);
 		}
-		strncpy(path, filename, sizeof(path) - 1);
+		strlcpy(path, filename, sizeof(path) - 1);
 		if (is_executable(path))
 			return path;
 		else
@@ -346,7 +346,7 @@ static const char *find_executable(const char *filename)
 					continue;	/* Too long */
 				else {
 					pathlen = len;
-					strncpy(path, p, pathlen);
+					strlcpy(path, p, pathlen);
 				}
 			} else {
 				if (getcwd(p, PATH_MAX) == NULL)
@@ -477,8 +477,8 @@ int main(int argc, char **argv)
 	}
 
 	if ((getuid() !=0 ) || (geteuid() != 0)) {
-		fprintf(stderr, "%s requires root privileges to write to %s\n",
-			APP_NAME, TIMER_STATS);
+		fprintf(stderr, "%s requires root trace processes\n",
+			APP_NAME);
 		health_check_exit(EXIT_FAILURE);
 	}
 
