@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2018 Canonical, Ltd.
+ * Copyright (C) 2013-2019 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
 #include <arpa/inet.h>
 #include <netdb.h>
 #include <dirent.h>
+#include <bsd/string.h>
 
 #include "list.h"
 #include "proc.h"
@@ -37,10 +38,6 @@
 #include "health-check.h"
 #include "net.h"
 
-#ifndef LINE_MAX
-#define LINE_MAX	(4096)
-#endif
-
 #define NET_HASH_SIZE	(1993)
 
 typedef struct {
@@ -137,7 +134,7 @@ static net_hash_t *net_hash_add(const char *path, const uint64_t inode, const pi
 		return NULL;
 	}
 
-	strncpy(n->path, path, PATH_MAX);
+	strlcpy(n->path, path, PATH_MAX);
 	n->inode = inode;
 	n->proc = proc_cache_find_by_pid(pid);
 	n->fd = fd;
@@ -247,7 +244,7 @@ static int net_cache_inodes_pid(const pid_t pid)
 
 	while ((d = readdir(fds)) != NULL) {
 		uint64_t inode;
-		char tmp[LINE_MAX];
+		char tmp[PATH_MAX + sizeof(d->d_name) + 2];
 		char link[PATH_MAX];
 		uint32_t fd;
 
@@ -301,7 +298,7 @@ static void net_inet4_resolve(char *name, const size_t len, struct sockaddr_in *
 	if (getnameinfo((struct sockaddr *)sin, sizeof(*sin), name, len,
 		NULL, 0, NI_NUMERICHOST) == 0)
 		return;
-	strncpy(name, "<unknown>", len);
+	strlcpy(name, "<unknown>", len);
 	return;
 }
 
@@ -319,7 +316,7 @@ static void net_inet6_resolve(char *name, const size_t len, struct sockaddr_in6
 	if (getnameinfo((struct sockaddr *)sin6, sizeof(*sin6), name, len,
 		NULL, 0, NI_NUMERICHOST) == 0)
 		return;
-	strncpy(name, "<unknown>", len);
+	strlcpy(name, "<unknown>", len);
 	return;
 }
 
@@ -359,8 +356,8 @@ static net_addr_info_t *net_addr_add(net_addr_info_t *addr)
  */
 static char *net_get_addr(net_addr_info_t *addr_info)
 {
-	static char tmp[256];
 	char buf[4096];
+	static char tmp[sizeof(buf) + 16];
 	in_port_t port;
 
 	switch (addr_info->type) {
@@ -524,7 +521,7 @@ void net_connection_dump(json_object *j_tests, double duration)
 				memset(&new_addr, 0, sizeof(new_addr));
 				new_addr.inode = nh->inode;
 				new_addr.type = NET_UNKNOWN;
-				strncpy(new_addr.u.path, nh->path, PATH_MAX);
+				strlcpy(new_addr.u.path, nh->path, sizeof(new_addr.u.path));
 				if ((addr_info = net_addr_add(&new_addr)) == NULL)
 					goto out;
 			}
@@ -635,7 +632,7 @@ static int net_unix_parse(void)
 		memset(&new_addr, 0, sizeof(new_addr));
 		new_addr.inode = inode;
 		new_addr.type = NET_UNIX;
-		strncpy(new_addr.u.path, path, PATH_MAX);
+		strlcpy(new_addr.u.path, path, PATH_MAX);
 		net_addr_add(&new_addr);
 	}
 	(void)fclose(fp);
